@@ -1,6 +1,6 @@
 
 /*
- * $Id: squid.h,v 1.19.4.47 1996/09/03 15:50:09 wessels Exp $
+ * $Id: squid.h,v 1.19.4.49 1996/09/11 21:38:46 wessels Exp $
  *
  * AUTHOR: Duane Wessels
  *
@@ -66,6 +66,9 @@
 #endif
 #if HAVE_NETDB_H && !defined(_SQUID_NETDB_H_)	/* protect NEXTSTEP */
 #define _SQUID_NETDB_H_
+#ifdef _SQUID_NEXT_
+#include <netinet/in_systm.h>
+#endif
 #include <netdb.h>
 #endif
 #if HAVE_PWD_H
@@ -260,6 +263,9 @@ extern char version_string[];	/* main.c */
 extern char appname[];		/* main.c */
 extern struct in_addr local_addr;	/* main.c */
 extern char localhost[];
+extern int opt_udp_hit_obj;	/* main.c */
+extern int opt_mem_pools;	/* main.c */
+extern int opt_forwarded_for;	/* main.c */
 
 
 /* Prototypes and definitions which don't really deserve a seaprate
