@@ -1,5 +1,5 @@
 /*
- * $Id: store_clean.c,v 1.1.2.2 1996/08/12 20:09:28 wessels Exp $
+ * $Id: store_clean.c,v 1.1.2.4 1996/08/19 19:51:12 wessels Exp $
  *
  * DEBUG: section 36    Cache Directory Cleanup
  * AUTHOR: Duane Wessels
@@ -47,47 +47,53 @@
 #endif /* HAVE_NDIR_H */
 #endif /* HAVE_DIRENT_H */
 
+static int rev_int_sort _PARAMS((int *, int *));
+
+static int rev_int_sort(i1, i2)
+     int *i1;
+     int *i2;
+{
+    return *i2 - *i1;
+}
+
 void storeDirClean()
 {
-    static int dirno = 0;
-    static int subdirno = 0;
-    static DIR *dp = NULL;
+    static int index = 0;
+    DIR *dp = NULL;
     struct dirent *de = NULL;
     static char p2[MAXPATHLEN + 1];
     static char p1[MAXPATHLEN + 1];
+    int files[20];
     int fileno;
-    int count = 0;
-    sprintf(p1, "%s/%02d", swappath(dirno), subdirno);
+    int n = 0;
+    int k = 0;
+    sprintf(p1, "%s/%02d",
+	swappath(index),
+	(index / ncache_dirs) % SWAP_DIRECTORIES);
     debug(36, 3, "storeDirClean: Cleaning directory %s\n", p1);
+    dp = opendir(p1);
     if (dp == NULL) {
-	dp = opendir(p1);
-	if (dp == NULL) {
-	    debug(36, 0, "storeDirClean: %s: %s\n", p1, xstrerror());
-	    fatal_dump(NULL);
-	}
+	debug(36, 0, "storeDirClean: %s: %s\n", p1, xstrerror());
+	fatal_dump(NULL);
     }
-    while ((de = readdir(dp))) {
+    while ((de = readdir(dp)) && k < 20) {
 	if (sscanf(de->d_name, "%d", &fileno) != 1)
 	    continue;
 	if (file_map_bit_test(fileno))
 	    continue;
-	sprintf(p2, "%s/%s", p1, de->d_name);
-	debug(36, 3, "storeDirClean: Cleaning file %d\n", fileno);
-	if (safeunlink(p2, 0) == 0)
-	    count++;
-	if (count == 10)
-	    break;
+	files[k++] = fileno;
     }
-    debug(36, count ? 1 : 3, "storeDirClean: Cleaned %d unused files from %s\n",
-	count, p1);
-    if (de == NULL) {
-	closedir(dp);
-	dp = NULL;
-	if (++subdirno == SWAP_DIRECTORIES) {
-	    subdirno = 0;
-	    dirno++;
-	}
-	if (dirno == ncache_dirs)
-	    dirno = 0;
+    closedir(dp);
+    index++;
+    if (k == 0)
+	return;
+    qsort(files, k, sizeof(int), (QS) rev_int_sort);
+    if (k > 10)
+	k = 10;
+    for (n = 0; n < k; n++) {
+	debug(36, 3, "storeDirClean: Cleaning file %d\n", files[n]);
+	sprintf(p2, "%s/%d", p1, files[n]);
+	safeunlink(p2, 0);
     }
+    debug(36, 1, "Cleaned %d unused files from %s\n", k, p1);
 }
